@@ -33,9 +33,9 @@ class JunosDevice(linux.LinuxDevice):
         if not self.configure_mode:
             self.configure_mode = True
             self._enter_configure_mode()
-        #self.cli("show version")
-        self.spus = self._get_spus(with_log = False)
+        self._get_spus(with_log = False)
         self._preconfig()
+        self.log("%s = %s\n" %(self.name, json.dumps(self.attributes, indent=4)))
 
     def __del__ (self):
         '''
@@ -82,7 +82,8 @@ class JunosDevice(linux.LinuxDevice):
             linux.LinuxDevice.cmd(self, "run start shell csh", 
                     expect = self.original_prompt, timeout = 3, with_log = False)
             prompt = "\[NETDEVICE\][\$\#] "
-            linux.LinuxDevice.cmd(self, self.PROMPT_SET_CSH, expect = prompt, timeout=1, log_level = self.LOG_DEBUG)
+            linux.LinuxDevice.cmd(self, self.PROMPT_SET_CSH, expect = prompt,
+                    timeout=1, with_log = False)
             output = linux.LinuxDevice.cmd(self, cmd, expect = prompt,
                     timeout = timeout, **kwargs)
             linux.LinuxDevice.cmd(self, "exit", with_log = False)
@@ -153,7 +154,7 @@ class JunosDevice(linux.LinuxDevice):
             if "commit" in c:
                 # Wait the commit finish in case of HA.
                 self.terminate_loop = True
-                linux.LinuxDevice.cmd(self, "show | compare rollback 1", **kwargs)
+                #linux.LinuxDevice.cmd(self, "show | compare rollback 1 | no-more", **kwargs)
 
             if kwargs.get('parse', None):
                 #self["log_level"] = self["log_level"] + 1
@@ -181,7 +182,7 @@ class JunosDevice(linux.LinuxDevice):
             tnp_addr: tnp address to execute, if not execut the command on
                       every SPU.
         '''
-        spus = kwargs.get("tnp_addr", False) and [kwargs["tnp_addr"]] or self.spus
+        spus = kwargs.get("tnp_addr", False) and [kwargs["tnp_addr"]] or self["spus"]
 
         linux.LinuxDevice.cmd(self, "run start shell csh",
                 expect = self.original_prompt, timeout = 3, with_log = False)
@@ -343,11 +344,11 @@ class JunosDevice(linux.LinuxDevice):
         '''
 
         version = self.cli("show version", parse = "software-information",
-                log_level = self.LOG_DEBUG)
+                with_log = False)
         self.model = version and version[0]["product-model"] or "Unknown"
         #self.junos_version = version and version[0]["junos-version"] or "Unknown"
         cluster = self.cli("show chassis cluster status",
-                parse = "redundancy-group", log_level = self.LOG_DEBUG)
+                parse = "redundancy-group", with_log = False)
         self.isha = cluster and True or False
 
         if self.model.lower() in ["srx320", "srx550m", "vsrx", "srx345"]:
@@ -357,18 +358,16 @@ class JunosDevice(linux.LinuxDevice):
         else:
             # List all the SPUs' TNPaddr on high end:
             spus = []
-            results = self.cmd('tnpdump', log_level = self.LOG_DEBUG)
+            results = self.cmd('tnpdump', with_log = False)
             f = StringIO(results)
             for i in f.readlines():
                 if ".pic" in i:
                     tmp = i.split()
                     spus.append(tmp[0])
             f.close()
-
-        self.log("Hostname:      %s" %(version[0]["host-name"]))
-        self.log("product-model: %s" %(version[0]["product-model"]))
-        #self.log("junos-version: %s" %(version[0]["junos-version"]))
-        self.log("spus:          %s" %(json.dumps(spus, indent=4)))
+        self["product-model"] = version[0]["product-model"]
+        self["spus"] = spus
+        self["junos-version"] = version[0]["junos-version"]
         return spus
 
     def _enter_configure_mode (self, timeout = 60):
@@ -380,13 +379,14 @@ class JunosDevice(linux.LinuxDevice):
             self.prompt = "%s@%s[\$\#\>] " %(self["username"], self.name)
         else:
             self.prompt = "%s[\$\#\>] " %(self["username"])
-        linux.LinuxDevice.cmd(self, "cli", timeout = timeout)
+        linux.LinuxDevice.cmd(self, "cli", timeout = timeout, with_log = False)
 
         if self.name:
             self.prompt = r"\[edit\]\r\n%s@%s#" %(self["username"], self.name)
         else:
             self.prompt = r"\[edit\]\r\n%s#" %(self["username"])
-        linux.LinuxDevice.cmd(self, "configure", timeout = timeout)
+        linux.LinuxDevice.cmd(self, "configure", timeout = timeout,
+                with_log = False)
 
     def _preconfig(self):
         '''
@@ -503,18 +503,16 @@ class JunosDevice(linux.LinuxDevice):
                 #    ipaddr = ipaddress.ip_interface(ipaddr)
                 #interface[family_name].append(ipaddr)
                 interface[family_name].append(ipaddress.ip_interface(unicode(ipaddr)))
-
-        #print(dir(interface["inet"][0]))
-        #print(interface["inet"][0].ip)
-        #print(interface["inet"][0].is_private)
-        #print(interface["inet"][0].is_reserved)
-        #print(interface["inet"][0].is_global)
         return interface
 
     def x_configure_interface (self, *args, **kwargs):
         """
         Re-configure the interface with the given parameters.
-        for example:
+
+        From release1.0.6, we will only configure the interfaces themselves,
+        won't configure the zone and other things.
+
+        call examples:
             int0 = {"name": "xe-1/0/0",
                     "inet": "41.0.0.111/24",
                     "inet6": "2001::111/64",
@@ -522,10 +520,6 @@ class JunosDevice(linux.LinuxDevice):
             dut.x_configure_interface(int0)
         """
         #print("%s.%s invoked" %(self.__class__.__name__, sys._getframe().f_code.co_name))
-
-        self.configure('delete security zones', **kwargs)
-        self.configure('delete security policies', **kwargs)
-        self.configure('set security policies default-policy permit-all', **kwargs)
         for arg in args:
             if not "name" in arg.keys():
                 continue
@@ -536,16 +530,7 @@ class JunosDevice(linux.LinuxDevice):
             if "inet6" in arg.keys():
                 self.configure("set security forwarding-options family inet6 mode flow-based", **kwargs)
                 self.configure("set interfaces %s unit %s family inet6 address %s" %(name[0], name[1], arg["inet6"]), **kwargs)
-             
-            # configure zone.
-            if "zone" in arg.keys():
-                self.configure('set security zones security-zone %s host-inbound-traffic system-services all' %(arg["zone"]), **kwargs)
-                self.configure('set security zones security-zone %s host-inbound-traffic protocols all' %(arg["zone"]), **kwargs)
-                self.configure('set security zones security-zone %s interfaces %s' %(arg["zone"], arg['name']))
-            self.interface[arg["name"]] = arg
-
         self.configure("commit", **kwargs)
-        self.log("interface changes: %s\n" %(json.dumps(args, indent=4)))
 
     def x_print_session (self, sessions):
         '''
