@@ -157,6 +157,8 @@ class LinuxDevice(object):
         self.connected = False
         self.random = random.randint(2, len(color_dict) - 5)
 
+        if not self["type"]:
+            self["type"] = 'Linux'
         # Parse the attribute, firstly the global configuration, then the
         # parameters, then the url parameters.
         #for k,v in default.iteritems():
@@ -205,7 +207,9 @@ class LinuxDevice(object):
                 self["name"] = self["name"] and self["name"] or "None"
             #self.del__configure_interface()
             self._preconfig()
-        self.log("%s = %s\n" %(self.name, json.dumps(self.attributes, indent=4)))
+
+        if self["type"] == 'Linux':
+            self.log("%s = %s\n" %(self.name, json.dumps(self.attributes, indent=4)))
         #self.x_get_interface()
         #self.log("interface = %s\n" %(json.dumps(self.interface, indent=4)))
 
@@ -274,14 +278,15 @@ class LinuxDevice(object):
             error = (i < len(prompt)) and prompt[i] or "None"
             self.log('Login failed: %s' %(error), color = "red")
             raise Exception ('Login failed: %s' %(error))
-        self.log("succeed to %s %s.\n" %(self["scheme"], self["hostname"]), color = "green")
+        #self.log("succeed to %s %s.\n" %(self["scheme"], self["hostname"]), color = "green")
+        self.log("succeed!", color = "green")
 
-        if (self.attributes.get("type", 'Linux') == 'Junos'):
+        if (self["type"] == 'Junos'):
             # Second phase
             # For Junos device, enter shell and Eat the prompt before send line.
             # Since cmd() method might be overided, call the original one.
             LinuxDevice.cmd(self, "start shell", expect = self.original_prompt,
-                    log_level = LOG_DEBUG)
+                    with_log = False, log_level = LOG_DEBUG)
 
         # need root privilage to configure the interface
         if self["username"] != "root" and self.attributes.get("root_password"):
@@ -971,7 +976,7 @@ class LinuxDevice(object):
                 self.interface[arg["name"]]["name"] = arg[0]
                 self.interface[arg["name"]]["inet"] = arg[1]
                 self.interface[arg["name"]]["inet6"] = arg[2]
-        self.log("interface changes: %s\n" %(json.dumps(args, indent=4)))
+        #self.log("interface changes: %s\n" %(json.dumps(args, indent=4)))
 
     def x_configure_route (self, local, gateway, remote):
         """
